function area = areaOfRing(outerRadius,innerRadius)
%areaOfRing computes area of a ring, given inner radius and outer
%radius
%
%  formal parameters: 
%       outerRadius: outer radius of a ring (scalar number)
%       innerRadius: inner radius of a ring (scalar number)
%
%  result
%       area: the area of the ring (scalar number)
%
%  example:
%       >> areaOfRing(5,3)
%         ans =
%               50.24
%
%       >>
%
% P.Conrad 10/15/2006 for CISC106     
area = areaOfDisc(outerRadius) - areaOfDisc(innerRadius);
return;
end
